--
-- Selected TOC Entries:
--
--
-- TOC Entry ID 2 (OID 1961065)
--
-- Name: cafproxy Type: TABLE Owner: aliphe
--

CREATE TABLE cafproxy (
	object_id integer NOT NULL,
	user_id integer NOT NULL,
	port varchar(20) NOT NULL,
	dbidsn character varying(250),
	cipher character varying,
	key character varying,
	usercipher character varying,
	userkey character varying,
	compression character varying(20),
	Constraint cafproxy_pkey Primary Key (object_id)
);

